"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useApiFactory = void 0;
/* eslint-disable no-param-reassign */
const react_1 = require("react");
const useApiExtends_1 = require("./useApiExtends");
const logger_1 = require("../logger");
const keyboard_1 = require("../keyboard");
/**
 * Initializes a new api instance
 * @param gridRootRef
 * @param apiRef
 * @param selectionKey
 */
function useApiFactory(gridRootRef, apiRef, selectionKey) {
    const logger = (0, logger_1.useLogger)('useApiFactory');
    const [initialised, setInit] = (0, react_1.useState)(false);
    const publishEvent = (0, react_1.useCallback)((name, ...args) => {
        logger.debug(`Publishing event ${name}`);
        apiRef.current.emit(name, ...args);
    }, [logger, apiRef]);
    const subscribeEvent = (0, react_1.useCallback)((event, handler) => {
        logger.debug(`Subscribing to event: ${event}`);
        apiRef.current.on(event, handler);
        const api = apiRef.current;
        return () => {
            logger.debug(`Removing event listener: ${event}`);
            api.removeListener(event, handler);
        };
    }, [apiRef, logger]);
    (0, react_1.useEffect)(() => {
        logger.debug('Initializing grid api.');
        apiRef.current.isInitialised = true;
        apiRef.current.rootElementRef = gridRootRef;
        apiRef.current.selectionKey = selectionKey !== null && selectionKey !== void 0 ? selectionKey : 'id';
        setInit(true);
    }, [selectionKey, gridRootRef, apiRef, logger]);
    const getCellElementByCoordinates = (0, react_1.useCallback)((coordinates) => {
        var _a;
        const selector = (0, keyboard_1.createCellQuerySelector)(coordinates);
        return (_a = gridRootRef.current) === null || _a === void 0 ? void 0 : _a.querySelector(selector);
    }, [gridRootRef]);
    const getColumnElementByCoordinates = (0, react_1.useCallback)((coordinates) => {
        var _a;
        const selector = (0, keyboard_1.createColumnQuerySelector)(coordinates);
        return (_a = gridRootRef.current) === null || _a === void 0 ? void 0 : _a.querySelector(selector);
    }, [gridRootRef]);
    const apiMethods = {
        subscribeEvent,
        dispatchEvent: publishEvent,
        getCellElementByCoordinates,
        getColumnElementByCoordinates,
    };
    (0, useApiExtends_1.useApiExtends)(apiRef, apiMethods, 'CoreApi');
    return initialised;
}
exports.useApiFactory = useApiFactory;
