"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColumnGrid = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const react_virtualized_1 = require("react-virtualized");
const CellMeasureWrapper_1 = tslib_1.__importDefault(require("../cellMeasurer/CellMeasureWrapper"));
const clsx_1 = tslib_1.__importDefault(require("clsx"));
const Tooltip_1 = tslib_1.__importDefault(require("@mui/material/Tooltip"));
const rowSelection_1 = require("../rowSelection");
const styles_1 = require("@mui/styles");
const helpers_1 = require("../helpers");
const flattenDeep_1 = tslib_1.__importDefault(require("lodash/flattenDeep"));
const keyboard_1 = require("../keyboard");
const logger_1 = require("../logger");
const components_1 = require("./components");
const api_1 = require("../api");
const KeyboardArrowRight_1 = tslib_1.__importDefault(require("@mui/icons-material/KeyboardArrowRight"));
const KeyboardArrowDown_1 = tslib_1.__importDefault(require("@mui/icons-material/KeyboardArrowDown"));
const useStyles = (0, styles_1.makeStyles)((theme) => ({
    defaultHeader: {
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        height: '100%',
        width: '100%',
        boxSizing: 'border-box',
        background: '#efefef',
        cursor: 'default',
        border: '1px solid #ccc',
    },
    headerContainer: {
        outline: 'none',
        position: 'sticky !important',
        top: 0,
        zIndex: 1,
        'scrollbar-width': 'none',
        '&::-webkit-scrollbar': {
            display: 'none',
        },
    },
    contentSpan: {
        textAlign: 'center',
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        width: '100%',
        height: '100%',
    },
}));
exports.ColumnGrid = react_1.default.memo(({ minColumnWidth, minRowHeight, width, getColumnWidth, apiRef, theme, coords, onScrollHeader, onColumnCollapse, columns, nestedColumnsProps, nestedHeaders, nestedRowsEnabled, data, overscanColumnCount, overscanRowCount, scrollLeft, disableSort, sort, headerId, }) => {
    const classes = useStyles();
    const logger = (0, logger_1.useLogger)('ColumnGrid');
    const cache = (0, react_1.useMemo)(() => {
        /**
         * @todo We might provide the same layer with fixed  as we did for gridWrapper
         */
        const options = {
            defaultWidth: minColumnWidth,
            defaultHeight: minRowHeight,
            //Width and height are fixed
            //Width is calculated on useHeaders hook
            //Height is never going to expand to avoid conflicts
            fixedWidth: true,
            fixedHeight: true,
            minHeight: minRowHeight,
            minWidth: minColumnWidth,
            /**
             * @todo We might need to review if this impacts any performance overall but i think this could be a boost
             * since we have fixed sizes therefore the calculation afterwards will likely be the same
             */
            keyMapper: () => 1,
        };
        return new react_virtualized_1.CellMeasurerCache(options);
    }, [minColumnWidth, minRowHeight]);
    const gridRef = (0, react_1.useRef)(null);
    const cacheRef = (0, react_1.useRef)(cache);
    const loggerRef = (0, react_1.useRef)(logger);
    (0, react_1.useEffect)(() => {
        loggerRef.current = logger;
    }, [logger]);
    (0, react_1.useEffect)(() => {
        cacheRef.current = cache;
    }, [cache]);
    //Stores the headers sort configuration (whether they have sort disabled or not)
    const headersSortDisabledMap = (0, react_1.useMemo)(() => {
        const flattenData = (0, flattenDeep_1.default)(data);
        return flattenData.reduce((mapping, cell) => {
            const updatedMap = Object.assign({}, mapping);
            if (typeof disableSort === 'boolean' && disableSort) {
                updatedMap[cell.id] = true;
            }
            else if (cell.isNested || cell.id === rowSelection_1.ROW_SELECTION_HEADER_ID || cell.dummy) {
                updatedMap[cell.id] = true;
            }
            else if ((0, helpers_1.isFunctionType)(disableSort)) {
                updatedMap[cell.id] = disableSort(cell);
            }
            else {
                updatedMap[cell.id] = false;
            }
            return updatedMap;
        }, {});
    }, [data, disableSort]);
    // clear cache and recompute when data changes OR when the container width changes
    const recomputeSizes = (0, react_1.useCallback)(() => {
        var _a, _b;
        loggerRef.current.debug('Recomputing Sizes');
        (_a = cacheRef.current) === null || _a === void 0 ? void 0 : _a.clearAll();
        (_b = gridRef.current) === null || _b === void 0 ? void 0 : _b.recomputeGridSize();
    }, []);
    (0, api_1.useApiEventHandler)(apiRef, 'DATA_CHANGED', recomputeSizes);
    (0, api_1.useApiEventHandler)(apiRef, 'GRID_RESIZE', recomputeSizes);
    (0, api_1.useApiEventHandler)(apiRef, 'COLUMNS_CHANGED', recomputeSizes);
    const headerRendererWrapper = (0, react_1.useCallback)(({ style, cell, ref, columnIndex, rowIndex }) => {
        var _a;
        const { title, renderer } = cell;
        const column = columns[columnIndex];
        //in case its not found, we set to true
        const isSortDisabled = nestedRowsEnabled ? true : headersSortDisabledMap[cell.id];
        const sortComponent = isSortDisabled || cell.accessor !== (sort === null || sort === void 0 ? void 0 : sort.accessor) ? null : (react_1.default.createElement("span", null, react_1.default.createElement(components_1.SortIndicator, { order: sort === null || sort === void 0 ? void 0 : sort.order })));
        let headerClassName = '';
        if (!cell.dummy && cell.isNested) {
            headerClassName = (0, clsx_1.default)(classes.defaultHeader, theme === null || theme === void 0 ? void 0 : theme.headerClass, theme === null || theme === void 0 ? void 0 : theme.nestedHeaderClass, cell.className);
        }
        if (!cell.dummy && !cell.isNested) {
            headerClassName = (0, clsx_1.default)(classes.defaultHeader, theme === null || theme === void 0 ? void 0 : theme.headerClass, cell.className);
        }
        //If the cell is selected we set the column as selected too
        if (!cell.dummy && coords.colIndex === columnIndex && !cell.isNested && rowIndex === 0) {
            headerClassName = (0, clsx_1.default)(headerClassName, theme === null || theme === void 0 ? void 0 : theme.currentColumnClass);
        }
        let children = title;
        if (renderer) {
            children = renderer({
                column: cell,
                className: headerClassName,
                columnIndex,
                apiRef,
            });
        }
        else if (cell.tooltip) {
            children = (react_1.default.createElement(Tooltip_1.default, Object.assign({ title: cell.tooltip, placement: 'top' }, cell.tooltipProps),
                react_1.default.createElement("span", { className: headerClassName }, title)));
        }
        const isSpannerAndNested = cell.colSpan && cell.isNested && !cell.dummy;
        const defaultZIndex = cell.dummy ? 0 : 1;
        const wrapperStyles = Object.assign(Object.assign({}, style), { zIndex: isSpannerAndNested ? 999 : defaultZIndex });
        const wrapper = child => {
            //Add navigationProps in case its a normal cell navigable
            const navigationProps = cell.dummy
                ? {}
                : (0, keyboard_1.createCellQueryProperties)({
                    role: 'columnheader',
                    colIndex: columnIndex,
                    rowIndex,
                });
            return (react_1.default.createElement("div", Object.assign({ ref: ref }, navigationProps, { className: headerClassName, style: wrapperStyles }),
                react_1.default.createElement("span", { onClick: isSortDisabled ? undefined : () => apiRef.current.toggleSort(cell.id), className: classes.contentSpan },
                    child,
                    sortComponent)));
        };
        // support nested column
        if (nestedColumnsProps === null || nestedColumnsProps === void 0 ? void 0 : nestedColumnsProps.nestedColumns) {
            const id = String(column[apiRef.current.selectionKey]);
            const depth = apiRef.current.getColumnDepth(id);
            const nestedMargin = ((_a = nestedColumnsProps === null || nestedColumnsProps === void 0 ? void 0 : nestedColumnsProps.nestedColumnMargin) !== null && _a !== void 0 ? _a : 10) * depth;
            //Parent collapse renders an additional layer with collapse controls
            if (column.__children && rowIndex === 0) {
                const iconStyle = {
                    cursor: 'pointer',
                    right: 0,
                    position: 'absolute',
                };
                const isColumnExpanded = apiRef.current.isColumnExpanded(id);
                const handleCollapseClick = () => {
                    if (!id) {
                        return logger.error(`Column index ${columnIndex} does not have a key in order to toggle collapse!`);
                    }
                    //Select the target column if not selected
                    if (coords.rowIndex !== columnIndex) {
                        apiRef.current.selectCell(Object.assign(Object.assign({}, coords), { colIndex: columnIndex }));
                    }
                    apiRef.current.toggleColumnExpand(id);
                    if (onColumnCollapse) {
                        onColumnCollapse(id);
                    }
                };
                const renderExpandOrCollapseIcon = () => {
                    if (nestedColumnsProps === null || nestedColumnsProps === void 0 ? void 0 : nestedColumnsProps.iconRenderer) {
                        return nestedColumnsProps === null || nestedColumnsProps === void 0 ? void 0 : nestedColumnsProps.iconRenderer(handleCollapseClick, isColumnExpanded);
                    }
                    return isColumnExpanded ? (react_1.default.createElement(KeyboardArrowRight_1.default, { onClick: handleCollapseClick, fontSize: 'small', style: iconStyle })) : (react_1.default.createElement(KeyboardArrowDown_1.default, { onClick: handleCollapseClick, fontSize: 'small', style: iconStyle }));
                };
                const component = (react_1.default.createElement("div", { style: depth > 1 ? { marginLeft: nestedMargin } : {} },
                    children,
                    renderExpandOrCollapseIcon()));
                return wrapper(component);
            }
            //Nested columns need to be wrapped on the first cell with a marginLeft
            if (depth > 1 && rowIndex === 0) {
                const component = react_1.default.createElement("div", { style: { marginLeft: nestedMargin } }, children);
                return wrapper(component);
            }
        }
        return wrapper(children);
    }, [
        apiRef,
        classes.contentSpan,
        classes.defaultHeader,
        columns,
        coords,
        headersSortDisabledMap,
        logger,
        nestedColumnsProps,
        nestedRowsEnabled,
        onColumnCollapse,
        sort === null || sort === void 0 ? void 0 : sort.accessor,
        sort === null || sort === void 0 ? void 0 : sort.order,
        theme === null || theme === void 0 ? void 0 : theme.currentColumnClass,
        theme === null || theme === void 0 ? void 0 : theme.headerClass,
        theme === null || theme === void 0 ? void 0 : theme.nestedHeaderClass,
    ]);
    const cellMeasurerWrapperRenderer = (0, react_1.useCallback)(args => {
        var _a, _b;
        /** @todo Review the typings **/
        const cell = (_a = data[args.rowIndex]) === null || _a === void 0 ? void 0 : _a[args.columnIndex];
        if (!cell) {
            return null;
        }
        const style = Object.assign(Object.assign(Object.assign({}, args.style), cell.style), { width: getColumnWidth({ index: args.columnIndex }), userSelect: 'none' });
        const rendererProps = Object.assign(Object.assign({}, args), { cell,
            getColumnWidth });
        return (react_1.default.createElement(CellMeasureWrapper_1.default, { cache: cache, columnIndex: args.columnIndex, key: args.key, parent: args.parent, rowIndex: args.rowIndex, 
            //Disable rowSpanning in headers
            rowSpan: 0, colSpan: (_b = cell.colSpan) !== null && _b !== void 0 ? _b : 0, cellRenderer: headerRendererWrapper, rendererProps: rendererProps, style: style }));
    }, [cache, data, getColumnWidth, headerRendererWrapper]);
    const rowCount = (0, react_1.useMemo)(() => {
        return nestedHeaders ? nestedHeaders.length + 1 : 1;
    }, [nestedHeaders]);
    const onRefMount = (0, react_1.useCallback)(instance => {
        gridRef.current = instance;
    }, []);
    return (react_1.default.createElement(react_virtualized_1.Grid, { className: (0, clsx_1.default)(classes.headerContainer), id: headerId, ref: onRefMount, cellRenderer: cellMeasurerWrapperRenderer, deferredMeasurementCache: cache, rowHeight: cache.rowHeight, rowCount: rowCount, columnCount: columns.length, overscanRowCount: overscanRowCount !== null && overscanRowCount !== void 0 ? overscanRowCount : 2, overscanColumnCount: overscanColumnCount !== null && overscanColumnCount !== void 0 ? overscanColumnCount : 2, width: width, columnWidth: getColumnWidth, height: 100, autoHeight: true, onScroll: onScrollHeader, tabIndex: -1 }));
});
exports.default = exports.ColumnGrid;
