"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createData = void 0;
const tslib_1 = require("tslib");
const formatCellValue_1 = require("./formatCellValue");
const gridWrapper_1 = require("../gridWrapper");
const material_1 = require("@mui/material");
const react_1 = tslib_1.__importDefault(require("react"));
const helpers_1 = require("../helpers");
function createData({ selection, apiRef, rows }) {
    const columns = apiRef.current.getColumns();
    /**
     * @todo Refactor this function to small function utilities in order to make it way organized
     */
    const cellsList = rows.reduce((list, row, rowIndex) => {
        const updatedList = [...list];
        //Creates the cells for the current row
        const cells = columns.reduce((_cells, column, colIndex) => {
            const isDummy = apiRef.current.isMerged({ rowIndex, colIndex });
            if (isDummy) {
                return _cells;
            }
            const spanInfo = apiRef.current.getSpanProperties({ rowIndex, colIndex });
            const cellValue = row[column.accessor] !== undefined ? row[column.accessor] : '';
            const coords = {
                colIndex,
                rowIndex,
            };
            const value = column.cellRenderer
                ? column.cellRenderer({ row, column, coords })
                : (0, formatCellValue_1.formatCellValue)(cellValue);
            _cells.push({
                colSpan: spanInfo === null || spanInfo === void 0 ? void 0 : spanInfo.colSpan,
                rowSpan: spanInfo === null || spanInfo === void 0 ? void 0 : spanInfo.rowSpan,
                value,
            });
            return _cells;
        }, []);
        if (selection) {
            const isSelectable = selection.canSelect ? selection.canSelect(row) : true;
            if (isSelectable) {
                const selected = apiRef.current.isRowSelected(row[selection.key]);
                //Bind the rowSelection
                cells[cells.length - 1] = {
                    value: (react_1.default.createElement(material_1.Checkbox, { className: (0, helpers_1.isFunctionType)(selection.checkboxClass)
                            ? selection.checkboxClass({ row, column: columns[columns.length - 1] })
                            : selection.checkboxClass, checked: selected, onClick: () => apiRef.current.selectRow(row[selection.key]) })),
                };
            }
        }
        // if (nestedRowsEnabled && row.__children !== undefined) {
        //   const hasChildren = row.__children.length > 0
        //   const isExpanded = apiRef.current.isRowExpanded(rowIndex)
        //   if (hasChildren && isExpanded) {
        //     //We need to push into updatedList after the rowIndex and create the cells for this
        //     const createdCells = createData({
        //       selection,
        //       rows: row.__children,
        //       apiRef,
        //       nestedRowsEnabled,
        //       depth: currentDepth + 1
        //     })
        //
        //     createdCells.forEach((e, i) => {
        //       //The parent index is the root index plus the position of the child where we should insert
        //       childrenCells.push({
        //         parentIndex: rowIndex + i,
        //         cells: e
        //       })
        //     })
        //   }
        // }
        updatedList[rowIndex] = cells;
        return updatedList;
    }, []);
    //Add the children cells on the target destination
    // childrenCells.forEach(e => {
    //   const target = cellsList[e.parentIndex + 1]
    //   if (target) {
    //     cellsList.splice(e.parentIndex + 1, 0, e.cells)
    //   } else {
    //     cellsList[e.parentIndex + 1] = e.cells
    //   }
    // })
    return (0, gridWrapper_1.insertDummyCells)(cellsList);
}
exports.createData = createData;
