"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumericEditor = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const material_1 = require("@mui/material");
const styles_1 = require("@mui/styles");
const utils_1 = require("../utils");
const clsx_1 = tslib_1.__importDefault(require("clsx"));
const api_1 = require("../../api");
const createDefaultPaperProps_1 = require("./createDefaultPaperProps");
const EditorContainer_1 = tslib_1.__importDefault(require("./EditorContainer"));
const useStyles = (0, styles_1.makeStyles)((theme) => ({
    input: {
        width: '100%',
        height: '100%',
        resize: 'none',
        overflow: 'auto',
        border: 0,
        outline: 0,
        '&:focus': {
            border: 0,
            outline: 0,
        },
    },
}));
exports.NumericEditor = (0, react_1.forwardRef)(({ value, stopEditing, anchorRef, maxLength, validatorHook, additionalProps, apiRef, }, componentRef) => {
    const classes = useStyles();
    const [editingValue, setEditingValue] = (0, react_1.useState)(isNaN(Number(value)) ? '0' : String(value));
    const onAnchorResize = (0, react_1.useCallback)(() => {
        stopEditing();
    }, [stopEditing]);
    (0, api_1.useApiEventHandler)(apiRef, api_1.GRID_RESIZE, onAnchorResize);
    (0, react_1.useImperativeHandle)(componentRef, () => ({
        getValue: () => (editingValue === '' ? 0 : parseFloat(editingValue)),
    }), [editingValue]);
    const onKeyPress = (0, react_1.useCallback)((e) => {
        const regex = /^[0-9.,]+$/;
        //Only 0-9 with dot and comma
        if (!regex.test(e.key)) {
            e.preventDefault();
            e.stopPropagation();
        }
    }, []);
    const isValidValue = (0, react_1.useMemo)(() => {
        if (validatorHook) {
            return validatorHook(editingValue);
        }
        //Use default number validator
        return !isNaN(Number(editingValue));
    }, [editingValue, validatorHook]);
    const onTextAreaResizeMount = (0, react_1.useCallback)((ref) => {
        if (!ref) {
            return;
        }
        // eslint-disable-next-line no-param-reassign
        ref.selectionStart = ref.value.length;
        // eslint-disable-next-line no-param-reassign
        ref.selectionEnd = ref.value.length;
    }, []);
    const onEditorPortalClose = (0, react_1.useCallback)((event, reason) => {
        //Only allow to cancel if its invalid
        if (!isValidValue) {
            return stopEditing({ save: false });
        }
        if (reason === 'backdropClick') {
            return stopEditing({ save: true });
        }
        stopEditing({ save: false });
    }, [isValidValue, stopEditing]);
    const anchorStyle = anchorRef.style;
    const theme = apiRef.current.getTheme();
    const paperProps = (0, createDefaultPaperProps_1.createDefaultPaperProps)(anchorStyle, isValidValue, additionalProps, theme);
    const onKeyDown = (0, react_1.useCallback)((e) => {
        (0, utils_1.handleEditorKeydown)(e, stopEditing);
    }, [stopEditing]);
    const onChange = (0, react_1.useCallback)((e) => {
        setEditingValue(e.target.value.replace(',', '.'));
    }, []);
    return (react_1.default.createElement(EditorContainer_1.default, { anchorEl: anchorRef, onClose: onEditorPortalClose, PaperProps: paperProps },
        react_1.default.createElement(material_1.TextareaAutosize, Object.assign({}, additionalProps === null || additionalProps === void 0 ? void 0 : additionalProps.componentProps, { id: 'apollo-textarea', value: editingValue, ref: onTextAreaResizeMount, inputMode: 'decimal', onKeyPress: onKeyPress, onKeyDown: onKeyDown, onChange: onChange, autoFocus: true, "aria-label": "numeric apollo editor", minRows: 1, maxLength: maxLength, className: (0, clsx_1.default)(classes.input, additionalProps === null || additionalProps === void 0 ? void 0 : additionalProps.className), style: additionalProps === null || additionalProps === void 0 ? void 0 : additionalProps.style }))));
});
exports.default = exports.NumericEditor;
