"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEditorComponent = void 0;
const tslib_1 = require("tslib");
const TextEditor_1 = tslib_1.__importDefault(require("../components/TextEditor"));
const helpers_1 = require("../../helpers");
const columnGrid_1 = require("../../columnGrid");
const components_1 = require("../components");
const react_1 = tslib_1.__importDefault(require("react"));
/**
 * Creates the react element dynamically
 */
const getEditorComponent = (row, column, editorProps, onRefMount) => {
    // If any editor is passed we assume JSX.Element are returned
    // and that the ref is automatically attached
    if (column.editor) {
        // React-Is does not recognize correctly forward ref functions therefore we have our custom
        // handler for that
        const editorType = String(column.editor.$$typeof);
        const isForwardRefComponent = editorType.includes('react.forward_ref');
        if (isForwardRefComponent) {
            const forwardedEditor = column.editor;
            return react_1.default.createElement(forwardedEditor, Object.assign(Object.assign({}, editorProps), { ref: onRefMount }));
        }
        //Check the type of this editor
        if ((0, helpers_1.isFunctionType)(column.editor)) {
            return column.editor({ row, column, onRefMount, editorProps });
        }
        return column.editor;
    }
    // Handle all default forwardedRef components
    let EditorComponent = TextEditor_1.default;
    if (column.type === columnGrid_1.ColumnCellType.Calendar) {
        EditorComponent = components_1.CalendarEditor;
    }
    else if (column.type === columnGrid_1.ColumnCellType.Numeric) {
        EditorComponent = components_1.NumericEditor;
    }
    return react_1.default.createElement(EditorComponent, Object.assign(Object.assign({}, editorProps), { ref: onRefMount }));
};
exports.getEditorComponent = getEditorComponent;
