"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEvents = void 0;
const react_1 = require("react");
const logger_1 = require("../logger");
const keyboard_1 = require("../keyboard");
function useEvents(gridRootRef, apiRef) {
    const logger = (0, logger_1.useLogger)('useEvents');
    const createHandler = (0, react_1.useCallback)((name) => (...args) => apiRef.current.dispatchEvent(name, ...args), [apiRef]);
    const handleClickOrDoubleClickEvent = (0, react_1.useCallback)((event) => {
        let target = event.target;
        if (!target) {
            return logger.warn(`[onClickHandler] Target element not defined, value: ${target}`);
        }
        let parsedCoords;
        const isCell = (0, keyboard_1.isCellElement)(target);
        if (isCell) {
            parsedCoords = (0, keyboard_1.getCellCoordinatesFromDOMElement)(target);
        }
        else {
            //Check if the parent element is a cell
            if (!target.parentElement || !(0, keyboard_1.isCellElement)(target.parentElement)) {
                return;
            }
            parsedCoords = (0, keyboard_1.getCellCoordinatesFromDOMElement)(target.parentElement);
            target = target.parentElement;
        }
        if (!parsedCoords) {
            return logger.warn(`[onClickHandler] ${(0, keyboard_1.createCoordsParseWarning)(target.parentElement)}`);
        }
        const eventName = event.type === 'click' ? 'CELL_CLICK' : 'CELL_DOUBLE_CLICK';
        const payload = Object.assign({ event, element: target }, parsedCoords);
        apiRef.current.dispatchEvent(eventName, payload);
    }, [apiRef, logger]);
    (0, react_1.useEffect)(() => {
        var _a;
        if (gridRootRef && gridRootRef.current && ((_a = apiRef.current) === null || _a === void 0 ? void 0 : _a.isInitialised)) {
            logger.debug('Binding events listeners');
            const keyDownHandler = createHandler('keydown');
            const gridRootElem = gridRootRef.current;
            gridRootRef.current.addEventListener('click', handleClickOrDoubleClickEvent, {
                capture: true,
            });
            gridRootRef.current.addEventListener('dblclick', handleClickOrDoubleClickEvent, {
                capture: true,
            });
            document.addEventListener('keydown', keyDownHandler);
            //gridRootRef.current.addEventListener('keydown', keyDownHandler)
            // eslint-disable-next-line no-param-reassign
            apiRef.current.isInitialised = true;
            const api = apiRef.current;
            return () => {
                logger.debug('Clearing all events listeners');
                gridRootElem.removeEventListener('click', handleClickOrDoubleClickEvent, { capture: true });
                gridRootElem.removeEventListener('dblclick', handleClickOrDoubleClickEvent, {
                    capture: true,
                });
                //gridRootElem.removeEventListener('keydown', keyDownHandler)
                document.removeEventListener('keydown', keyDownHandler);
                /**
                 * @todo Review the need of this
                 * i think replacing gridRootElem.removeAllListeners would make more sense
                 */
                api.removeAllListeners();
            };
        }
    }, [gridRootRef, apiRef, logger, createHandler, handleClickOrDoubleClickEvent]);
}
exports.useEvents = useEvents;
