"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GridContainer = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const types_1 = require("../types");
const react_virtualized_1 = require("react-virtualized");
const columnGrid_1 = require("../columnGrid");
const logger_1 = require("../logger");
const api_1 = require("../api");
const scrollbarSize_1 = tslib_1.__importDefault(require("dom-helpers/scrollbarSize"));
const material_1 = require("@mui/material");
const DEFAULT_SCROLLBAR_SIZE = 14;
exports.GridContainer = react_1.default.memo(({ minColumnWidth, stretchMode, apiRef, columns, children, width, height, containerClassName, }) => {
    const logger = (0, logger_1.useLogger)('GridContainer');
    const calculatedScrollbarSize = (0, scrollbarSize_1.default)(true);
    //Added a default scrollbar size to avoid 0 spacing and overlaps of the scrollbar to the grid
    const scrollbarSize = calculatedScrollbarSize > 0 ? calculatedScrollbarSize : DEFAULT_SCROLLBAR_SIZE;
    const columnWidths = (0, react_1.useRef)({
        totalSize: 0,
        mapping: {},
    });
    /**
     * Helper that facades with getColumnWidth function provided by react-virtualize and either returns
     * the fixed width from our mapping or fetches directly from react-virtualize
     * @param getColumnWidth
     */
    const getColumnWidthHelper = (0, react_1.useCallback)(({ index }) => {
        const value = columnWidths.current.mapping[index];
        return isNaN(value) ? minColumnWidth : value;
    }, [minColumnWidth]);
    const calculateColumnWidths = (0, react_1.useCallback)((containerWidth) => {
        const { mapping, totalSize } = (0, columnGrid_1.createColumnWidthsMapping)(columns, containerWidth, minColumnWidth, stretchMode);
        //Just update with the new calculated (if it was otherwise it might have been a cached result)
        columnWidths.current = {
            totalSize,
            mapping,
        };
    }, [columns, minColumnWidth, stretchMode]);
    const render = (0, react_1.useCallback)((containerWidth, containerHeight = 500) => {
        const normalizedContainerWidth = stretchMode !== types_1.StretchMode.None ? containerWidth - scrollbarSize : containerWidth;
        //Invoke our column builder
        calculateColumnWidths(normalizedContainerWidth);
        logger.debug({
            containerWidth,
            containerHeight,
            scrollbarSize,
            stretchMode,
            normalizedContainerWidth,
            columnWidths: columnWidths.current,
            hasHorizontalScroll: stretchMode === types_1.StretchMode.None,
        });
        if (stretchMode !== types_1.StretchMode.None) {
            return (react_1.default.createElement(react_1.default.Fragment, null, children({
                width: containerWidth,
                height: containerHeight,
                getColumnWidth: getColumnWidthHelper,
                scrollLeft: 0,
            })));
        }
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(react_virtualized_1.ScrollSync, null, ({ onScroll, scrollLeft }) => (react_1.default.createElement(react_1.default.Fragment, null, children({
                width: containerWidth,
                height: containerHeight,
                getColumnWidth: getColumnWidthHelper,
                scrollLeft,
                onScroll,
            }))))));
    }, [calculateColumnWidths, children, getColumnWidthHelper, logger, scrollbarSize, stretchMode]);
    const onResize = (0, react_1.useCallback)((info) => {
        if (!apiRef.current.isInitialised) {
            return;
        }
        apiRef.current.dispatchEvent(api_1.GRID_RESIZE, info);
    }, [apiRef]);
    //In case of specified width and height, allow the control to the developer
    if (height && width) {
        return (react_1.default.createElement(material_1.Box, { id: 'apollo-root-fixed', height: height, width: width, className: containerClassName }, render(Number(width), Number(height))));
    }
    return (react_1.default.createElement(material_1.Box, { id: 'apollo-root-dynamic', height: '100%', width: '100%', className: containerClassName },
        react_1.default.createElement(react_virtualized_1.AutoSizer, { disableWidth: width !== undefined, disableHeight: height !== undefined, defaultHeight: Number(height), defaultWidth: Number(width), onResize: onResize }, ({ width, height }) => render(width, height))));
});
