"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isMetaKey = exports.isCtrlMetaKey = exports.isCtrlKey = exports.isPrintableChar = exports.isIndexOutOfBoundaries = void 0;
/**
 * Returns whether a given row coordinate is out of the given limit
 * @param index
 * @param min
 * @param max
 */
const constants_1 = require("../constants");
function isIndexOutOfBoundaries(index, min, max) {
    return index < min || index > max;
}
exports.isIndexOutOfBoundaries = isIndexOutOfBoundaries;
/**
 * Returns true if keyCode represents a printable character.
 *
 * @param {number} keyCode The keyboard key code.
 * @returns {boolean}
 */
function isPrintableChar(keyCode) {
    return (keyCode === 32 || // space
        (keyCode >= 48 && keyCode <= 57) || // 0-9
        (keyCode >= 96 && keyCode <= 111) || // numpad
        (keyCode >= 186 && keyCode <= 192) || // ;=,-./`
        (keyCode >= 219 && keyCode <= 222) || // []{}\|"'
        keyCode >= 226 || // special chars (229 for Asian chars)
        (keyCode >= 65 && keyCode <= 90)); // a-z
}
exports.isPrintableChar = isPrintableChar;
/**
 * Checks if passed key code is ctrl or cmd key.
 * Depends on what OS the code runs it check key code based on
 * different meta key codes.
 *
 * @param {number} keyCode The keyboard key code.
 * @returns {boolean}
 */
function isCtrlKey(keyCode) {
    const keys = [];
    //Ensure navigator is defined due to the fact this might be rendered on SSR
    if (navigator && navigator.platform.includes('Mac')) {
        keys.push(constants_1.KEY_CODES.COMMAND_LEFT, constants_1.KEY_CODES.COMMAND_RIGHT, constants_1.KEY_CODES.COMMAND_FIREFOX);
    }
    else {
        keys.push(constants_1.KEY_CODES.CONTROL);
    }
    return keys.includes(keyCode);
}
exports.isCtrlKey = isCtrlKey;
/**
 * Checks if passed key code is ctrl or cmd key.
 * This helper checks if the key code matches to meta keys
 * regardless of the OS on which it is running.
 *
 * @param {number} keyCode The keyboard key code.
 * @returns {boolean}
 */
function isCtrlMetaKey(keyCode) {
    return [
        constants_1.KEY_CODES.CONTROL,
        constants_1.KEY_CODES.COMMAND_LEFT,
        constants_1.KEY_CODES.COMMAND_RIGHT,
        constants_1.KEY_CODES.COMMAND_FIREFOX,
    ].includes(keyCode);
}
exports.isCtrlMetaKey = isCtrlMetaKey;
/**
 * @param {number} keyCode The keyboard key code.
 * @param {string} baseCode The list of the key codes to compare with.
 * @returns {boolean}
 */
// export function isKey(keyCode, baseCode) {
// 	const keys = baseCode.split('|')
// 	let result = false
//
// 	arrayEach(keys, key => {
// 		if (keyCode === KEY_CODES[key]) {
// 			result = true
//
// 			return false
// 		}
// 	})
//
// 	return result
// }
/**
 * @param {number} keyCode The keyboard key code.
 * @returns {boolean}
 */
function isMetaKey(keyCode) {
    const metaKeys = [
        constants_1.KEY_CODES.ARROW_DOWN,
        constants_1.KEY_CODES.ARROW_UP,
        constants_1.KEY_CODES.ARROW_LEFT,
        constants_1.KEY_CODES.ARROW_RIGHT,
        constants_1.KEY_CODES.HOME,
        constants_1.KEY_CODES.END,
        constants_1.KEY_CODES.DELETE,
        constants_1.KEY_CODES.BACKSPACE,
        constants_1.KEY_CODES.F1,
        constants_1.KEY_CODES.F2,
        constants_1.KEY_CODES.F3,
        constants_1.KEY_CODES.F4,
        constants_1.KEY_CODES.F5,
        constants_1.KEY_CODES.F6,
        constants_1.KEY_CODES.F7,
        constants_1.KEY_CODES.F8,
        constants_1.KEY_CODES.F9,
        constants_1.KEY_CODES.F10,
        constants_1.KEY_CODES.F11,
        constants_1.KEY_CODES.F12,
        constants_1.KEY_CODES.TAB,
        constants_1.KEY_CODES.PAGE_DOWN,
        constants_1.KEY_CODES.PAGE_UP,
        constants_1.KEY_CODES.ENTER,
        constants_1.KEY_CODES.ESCAPE,
        constants_1.KEY_CODES.SHIFT,
        constants_1.KEY_CODES.CAPS_LOCK,
        constants_1.KEY_CODES.ALT,
    ];
    return metaKeys.indexOf(keyCode) !== -1;
}
exports.isMetaKey = isMetaKey;
