"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCoordsParseWarning = exports.createSelectorElementNotFoundWarning = exports.getCellCoordinatesFromDOMElement = exports.isCellElement = exports.createColumnQuerySelector = exports.createCellQuerySelector = exports.createCellQueryProperties = void 0;
const createCellQueryProperties = ({ colIndex, rowIndex, role, accessor, }) => {
    const properties = {
        'aria-rowindex': rowIndex,
        'aria-colindex': colIndex,
        role,
    };
    if (accessor) {
        properties['data-accessor'] = accessor;
    }
    return properties;
};
exports.createCellQueryProperties = createCellQueryProperties;
const createCellQuerySelector = ({ colIndex, rowIndex }) => {
    return `[aria-colindex="${colIndex}"][aria-rowindex="${rowIndex}"][role="cell"]`;
};
exports.createCellQuerySelector = createCellQuerySelector;
const createColumnQuerySelector = ({ colIndex, rowIndex }) => {
    return `[aria-colindex="${colIndex}"][aria-rowindex="${rowIndex}"][role="columnheader"]`;
};
exports.createColumnQuerySelector = createColumnQuerySelector;
const isCellElement = (element) => {
    return (element === null || element === void 0 ? void 0 : element.getAttribute('role')) === 'cell';
};
exports.isCellElement = isCellElement;
/** @todo requires tests **/
const getCellCoordinatesFromDOMElement = (target) => {
    const colIndex = target.getAttribute('aria-colindex');
    const rowIndex = target.getAttribute('aria-rowindex');
    if (!colIndex || !rowIndex) {
        return undefined;
    }
    const parsedColIndex = Number(colIndex);
    const parsedRowIndex = Number(rowIndex);
    if (Number.isNaN(parsedRowIndex) || Number.isNaN(parsedColIndex)) {
        return undefined;
    }
    if (parsedRowIndex < 0 || parsedColIndex < 0) {
        return undefined;
    }
    return { colIndex: parsedColIndex, rowIndex: parsedRowIndex };
};
exports.getCellCoordinatesFromDOMElement = getCellCoordinatesFromDOMElement;
const createSelectorElementNotFoundWarning = ({ colIndex, rowIndex }) => {
    return `Cell DOM element not found with coordinates [${rowIndex},${colIndex}]. Selector used: ${(0, exports.createCellQuerySelector)({ colIndex, rowIndex })}`;
};
exports.createSelectorElementNotFoundWarning = createSelectorElementNotFoundWarning;
const createCoordsParseWarning = (element) => {
    return `Coordinates not extracted correctly from target ${element}, details: ${JSON.stringify({
        role: element === null || element === void 0 ? void 0 : element.getAttribute('role'),
        rowIndex: element === null || element === void 0 ? void 0 : element.getAttribute('aria-rowindex'),
        colIndex: element === null || element === void 0 ? void 0 : element.getAttribute('aria-colindex'),
    })}`;
};
exports.createCoordsParseWarning = createCoordsParseWarning;
