"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLoggerInstance = exports.localStorageAvailable = void 0;
function localStorageAvailable() {
    try {
        // Incognito mode might reject access to the localStorage for security reasons.
        // window isn't defined on Node.js
        // https://stackoverflow.com/questions/16427636/check-if-localstorage-is-available
        const key = '__apollo_debugger_key__';
        window.localStorage.setItem(key, key);
        window.localStorage.removeItem(key);
        return true;
    }
    catch (err) {
        return false;
    }
}
exports.localStorageAvailable = localStorageAvailable;
const LOG_LEVELS = ['debug', 'info', 'warn', 'error'];
// eslint-disable-next-line @typescript-eslint/no-empty-function
const empty = () => { };
/**
 * Returns a new logger instance
 * @param name
 * @param logLevel
 * @param appender
 */
function createLoggerInstance(name, logLevel) {
    const index = LOG_LEVELS.indexOf(logLevel);
    if (index === -1) {
        throw new Error(`Log level ${logLevel} not recognized.`);
    }
    const logger = LOG_LEVELS.reduce((e, method, i) => {
        const handler = Object.assign({}, e);
        if (i >= index) {
            handler[method] = (...args) => {
                const [message, ...rest] = args;
                if (typeof message === 'object' || Array.isArray(message)) {
                    console[method](`${name}%c: `, 'color:white', message, ...rest);
                }
                else {
                    console[method](`${name}%c: ${message}`, 'color:white', ...rest);
                }
            };
        }
        else {
            handler[method] = empty;
        }
        return handler;
    }, {});
    return logger;
}
exports.createLoggerInstance = createLoggerInstance;
