"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateMergeData = void 0;
const validators_1 = require("./validators");
const validationErrorMessages_1 = require("./validationErrorMessages");
function validateMergeData(data, rowCount, columnCount) {
    const validData = [];
    data.forEach(e => {
        if ((0, validators_1.containsNegativeValues)(e)) {
            console.error((0, validationErrorMessages_1.MERGED_NEGATIVE_VALUES)(e));
        }
        else if ((0, validators_1.isOutOfBounds)(e, rowCount, columnCount)) {
            console.error((0, validationErrorMessages_1.MERGED_OUT_OF_BONDS)(e));
        }
        else if ((0, validators_1.isSingleCell)(e)) {
            console.error((0, validationErrorMessages_1.MERGED_SINGLE_CELL)(e));
        }
        else if ((0, validators_1.isZeroSpan)(e)) {
            console.error((0, validationErrorMessages_1.MERGED_ZERO_SPAN)(e));
        }
        else if (validData.some(x => x.rowIndex === e.rowIndex && x.colIndex === e.colIndex)) {
            console.error((0, validationErrorMessages_1.MERGED_DUPLICATED)(e));
        }
        else if ((0, validators_1.isOverlapping)(e, validData)) {
            console.error((0, validationErrorMessages_1.MERGED_OVERLAP)(e));
        }
        else {
            validData.push(e);
        }
    });
    return validData;
}
exports.validateMergeData = validateMergeData;
