"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSort = void 0;
const react_1 = require("react");
const api_1 = require("../api");
const lodash_1 = require("lodash");
const logger_1 = require("../logger");
const columnGrid_1 = require("../columnGrid");
function useSort(apiRef) {
    const logger = (0, logger_1.useLogger)('useSort');
    const stateRef = (0, react_1.useRef)(null);
    const [sort, setSort] = (0, react_1.useState)(null);
    const sortRows = (0, react_1.useCallback)((rows, state, type) => {
        return type === undefined || type === columnGrid_1.ColumnCellType.TextArea
            ? (0, lodash_1.orderBy)([...rows], [e => e[state.accessor].toLowerCase()], [state.order])
            : (0, lodash_1.orderBy)([...rows], [state.accessor], [state.order]);
    }, []);
    const clearSort = (0, react_1.useCallback)(() => {
        if (!stateRef.current) {
            return;
        }
        logger.debug(`Clearing sort at accessor ${stateRef.current.accessor}`);
        stateRef.current = null;
        setSort(null);
        apiRef.current.updateRows(apiRef.current.getOriginalRows());
    }, [apiRef, logger]);
    const toggleSort = (0, react_1.useCallback)((columnId) => {
        var _a, _b;
        logger.debug(`Toggling sort for column id: ${columnId}`);
        const currentRows = apiRef.current.getRows();
        const column = apiRef.current.getColumnById(columnId);
        if (!column) {
            return logger.error(`Column id: ${columnId} not found at toggleSort`);
        }
        if ((column === null || column === void 0 ? void 0 : column.accessor) === ((_a = stateRef.current) === null || _a === void 0 ? void 0 : _a.accessor)) {
            const nextSort = ((_b = stateRef.current) === null || _b === void 0 ? void 0 : _b.order) === 'asc' ? 'desc' : 'asc';
            if (nextSort === 'asc') {
                clearSort();
            }
            else {
                stateRef.current = {
                    accessor: column.accessor,
                    order: nextSort,
                };
                setSort(stateRef.current);
                apiRef.current.updateRows((0, lodash_1.orderBy)([...currentRows], [stateRef.current.accessor], [stateRef.current.order]));
            }
        }
        else {
            stateRef.current = {
                accessor: column.accessor,
                order: 'asc',
            };
            setSort(stateRef.current);
            apiRef.current.updateRows((0, lodash_1.orderBy)([...currentRows], [stateRef.current.accessor], [stateRef.current.order]));
        }
    }, [apiRef, clearSort, logger]);
    const sortColumn = (0, react_1.useCallback)((columnId, order) => {
        var _a, _b;
        logger.debug(`Sorting ${columnId} with order ${order}`);
        const column = apiRef.current.getColumnById(columnId);
        if (!column) {
            return logger.error(`Column id: ${columnId} not found at sortColumn`);
        }
        // Ensure its not applied already
        if (((_a = stateRef.current) === null || _a === void 0 ? void 0 : _a.accessor) === column.accessor && ((_b = stateRef.current) === null || _b === void 0 ? void 0 : _b.order) === order) {
            return;
        }
        stateRef.current = {
            accessor: column.accessor,
            order,
        };
        setSort(stateRef.current);
        const currentRows = apiRef.current.getRows();
        apiRef.current.updateRows(sortRows(currentRows, stateRef.current, column.type));
    }, [apiRef, logger, sortRows]);
    const getSortState = (0, react_1.useCallback)(() => stateRef.current, []);
    const sortApi = {
        getSortState,
        toggleSort,
        sortColumn,
        clearSort,
    };
    (0, api_1.useApiExtends)(apiRef, sortApi, 'SortApi');
    return sort;
}
exports.useSort = useSort;
