"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTheme = void 0;
const api_1 = require("../api");
const react_1 = require("react");
const logger_1 = require("../logger");
function useTheme({ apiRef, options }) {
    const logger = (0, logger_1.useLogger)('useTheme');
    const loggerRef = (0, react_1.useRef)(logger);
    const api = (0, react_1.useRef)(apiRef.current);
    const [activeTheme, setActiveTheme] = (0, react_1.useState)(options);
    const themeRef = (0, react_1.useRef)(activeTheme);
    (0, react_1.useEffect)(() => {
        themeRef.current = activeTheme;
    }, [activeTheme]);
    (0, react_1.useEffect)(() => {
        api.current = apiRef.current;
    }, [apiRef]);
    (0, react_1.useEffect)(() => {
        loggerRef.current = logger;
    }, [logger]);
    (0, react_1.useEffect)(() => {
        loggerRef.current.debug('Theme options have changed');
        api.current.dispatchEvent('THEME_CHANGED', options);
        setActiveTheme(options);
    }, [options]);
    const changeTheme = (0, react_1.useCallback)((options) => {
        setActiveTheme(options);
    }, []);
    const getTheme = (0, react_1.useCallback)(() => {
        return themeRef.current;
    }, []);
    const themeApi = { changeTheme, getTheme };
    (0, api_1.useApiExtends)(apiRef, themeApi, 'ThemeApi');
    return activeTheme;
}
exports.useTheme = useTheme;
